"""RollerBearingUserSpecifiedProfile"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.bearings.roller_bearing_profiles import _1988
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_ROLLER_BEARING_USER_SPECIFIED_PROFILE = python_net_import(
    "SMT.MastaAPI.Bearings.RollerBearingProfiles", "RollerBearingUserSpecifiedProfile"
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.bearings.roller_bearing_profiles import _1979, _1981, _1992

    Self = TypeVar("Self", bound="RollerBearingUserSpecifiedProfile")
    CastSelf = TypeVar(
        "CastSelf",
        bound="RollerBearingUserSpecifiedProfile._Cast_RollerBearingUserSpecifiedProfile",
    )


__docformat__ = "restructuredtext en"
__all__ = ("RollerBearingUserSpecifiedProfile",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_RollerBearingUserSpecifiedProfile:
    """Special nested class for casting RollerBearingUserSpecifiedProfile to subclasses."""

    __parent__: "RollerBearingUserSpecifiedProfile"

    @property
    def roller_bearing_profile(self: "CastSelf") -> "_1988.RollerBearingProfile":
        return self.__parent__._cast(_1988.RollerBearingProfile)

    @property
    def roller_bearing_user_specified_profile(
        self: "CastSelf",
    ) -> "RollerBearingUserSpecifiedProfile":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class RollerBearingUserSpecifiedProfile(_1988.RollerBearingProfile):
    """RollerBearingUserSpecifiedProfile

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ROLLER_BEARING_USER_SPECIFIED_PROFILE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def data_to_use(self: "Self") -> "_1979.ProfileDataToUse":
        """mastapy._private.bearings.roller_bearing_profiles.ProfileDataToUse"""
        temp = self.wrapped.DataToUse

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Bearings.RollerBearingProfiles.ProfileDataToUse"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.bearings.roller_bearing_profiles._1979",
            "ProfileDataToUse",
        )(value)

    @data_to_use.setter
    @enforce_parameter_types
    def data_to_use(self: "Self", value: "_1979.ProfileDataToUse") -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Bearings.RollerBearingProfiles.ProfileDataToUse"
        )
        self.wrapped.DataToUse = value

    @property
    def number_of_points(self: "Self") -> "int":
        """int"""
        temp = self.wrapped.NumberOfPoints

        if temp is None:
            return 0

        return temp

    @number_of_points.setter
    @enforce_parameter_types
    def number_of_points(self: "Self", value: "int") -> None:
        self.wrapped.NumberOfPoints = int(value) if value is not None else 0

    @property
    def profile_to_fit(self: "Self") -> "_1981.ProfileToFit":
        """mastapy._private.bearings.roller_bearing_profiles.ProfileToFit"""
        temp = self.wrapped.ProfileToFit

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Bearings.RollerBearingProfiles.ProfileToFit"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.bearings.roller_bearing_profiles._1981", "ProfileToFit"
        )(value)

    @profile_to_fit.setter
    @enforce_parameter_types
    def profile_to_fit(self: "Self", value: "_1981.ProfileToFit") -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Bearings.RollerBearingProfiles.ProfileToFit"
        )
        self.wrapped.ProfileToFit = value

    @property
    def points(self: "Self") -> "List[_1992.UserSpecifiedProfilePoint]":
        """List[mastapy._private.bearings.roller_bearing_profiles.UserSpecifiedProfilePoint]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Points

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    def set_to_full_range(self: "Self") -> None:
        """Method does not return."""
        self.wrapped.SetToFullRange()

    @property
    def cast_to(self: "Self") -> "_Cast_RollerBearingUserSpecifiedProfile":
        """Cast to another type.

        Returns:
            _Cast_RollerBearingUserSpecifiedProfile
        """
        return _Cast_RollerBearingUserSpecifiedProfile(self)



"""ShaftSectionEndDamageResults"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._math.vector_3d import Vector3D
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_SHAFT_SECTION_END_DAMAGE_RESULTS = python_net_import(
    "SMT.MastaAPI.Shafts", "ShaftSectionEndDamageResults"
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.nodal_analysis import _87
    from mastapy._private.shafts import _44, _16, _17, _29
    from mastapy._private.materials import _292

    Self = TypeVar("Self", bound="ShaftSectionEndDamageResults")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ShaftSectionEndDamageResults._Cast_ShaftSectionEndDamageResults",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ShaftSectionEndDamageResults",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ShaftSectionEndDamageResults:
    """Special nested class for casting ShaftSectionEndDamageResults to subclasses."""

    __parent__: "ShaftSectionEndDamageResults"

    @property
    def shaft_section_end_damage_results(
        self: "CastSelf",
    ) -> "ShaftSectionEndDamageResults":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ShaftSectionEndDamageResults(_0.APIBase):
    """ShaftSectionEndDamageResults

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SHAFT_SECTION_END_DAMAGE_RESULTS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def displacement_angular(self: "Self") -> "Vector3D":
        """Vector3D

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DisplacementAngular

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector3d(temp)

        if value is None:
            return None

        return value

    @property
    def displacement_axial(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DisplacementAxial

        if temp is None:
            return 0.0

        return temp

    @property
    def displacement_linear(self: "Self") -> "Vector3D":
        """Vector3D

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DisplacementLinear

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector3d(temp)

        if value is None:
            return None

        return value

    @property
    def displacement_radial_magnitude(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DisplacementRadialMagnitude

        if temp is None:
            return 0.0

        return temp

    @property
    def displacement_radial_tilt_magnitude(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DisplacementRadialTiltMagnitude

        if temp is None:
            return 0.0

        return temp

    @property
    def displacement_twist(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DisplacementTwist

        if temp is None:
            return 0.0

        return temp

    @property
    def equivalent_alternating_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.EquivalentAlternatingStress

        if temp is None:
            return 0.0

        return temp

    @property
    def fatigue_damage(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FatigueDamage

        if temp is None:
            return 0.0

        return temp

    @property
    def fatigue_safety_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FatigueSafetyFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def fatigue_safety_factor_for_infinite_life(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FatigueSafetyFactorForInfiniteLife

        if temp is None:
            return 0.0

        return temp

    @property
    def force_angular(self: "Self") -> "Vector3D":
        """Vector3D

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ForceAngular

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector3d(temp)

        if value is None:
            return None

        return value

    @property
    def force_axial(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ForceAxial

        if temp is None:
            return 0.0

        return temp

    @property
    def force_linear(self: "Self") -> "Vector3D":
        """Vector3D

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ForceLinear

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector3d(temp)

        if value is None:
            return None

        return value

    @property
    def force_radial_magnitude(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ForceRadialMagnitude

        if temp is None:
            return 0.0

        return temp

    @property
    def force_torque(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ForceTorque

        if temp is None:
            return 0.0

        return temp

    @property
    def offset(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Offset

        if temp is None:
            return 0.0

        return temp

    @property
    def outer_diameter_to_achieve_fatigue_safety_factor_requirement(
        self: "Self",
    ) -> "float":
        """float"""
        temp = self.wrapped.OuterDiameterToAchieveFatigueSafetyFactorRequirement

        if temp is None:
            return 0.0

        return temp

    @outer_diameter_to_achieve_fatigue_safety_factor_requirement.setter
    @enforce_parameter_types
    def outer_diameter_to_achieve_fatigue_safety_factor_requirement(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.OuterDiameterToAchieveFatigueSafetyFactorRequirement = (
            float(value) if value is not None else 0.0
        )

    @property
    def outer_radius_to_achieve_shaft_fatigue_safety_factor_requirement(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OuterRadiusToAchieveShaftFatigueSafetyFactorRequirement

        if temp is None:
            return 0.0

        return temp

    @property
    def reliability_for_infinite_life(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReliabilityForInfiniteLife

        if temp is None:
            return 0.0

        return temp

    @property
    def section_end(self: "Self") -> "_87.SectionEnd":
        """mastapy._private.nodal_analysis.SectionEnd

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SectionEnd

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(temp, "SMT.MastaAPI.NodalAnalysis.SectionEnd")

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.nodal_analysis._87", "SectionEnd"
        )(value)

    @property
    def shaft_reliability(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShaftReliability

        if temp is None:
            return 0.0

        return temp

    @property
    def static_safety_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StaticSafetyFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def total_number_of_cycles(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TotalNumberOfCycles

        if temp is None:
            return 0.0

        return temp

    @property
    def din743201212_component_fatigue_limit_under_reversed_stress_sigma_zd_wk_sigma_bwk_tau_twk(
        self: "Self",
    ) -> "_44.StressMeasurementShaftAxialBendingTorsionalComponentValues":
        """mastapy._private.shafts.StressMeasurementShaftAxialBendingTorsionalComponentValues

        Note:
            This property is readonly.
        """
        temp = (
            self.wrapped.DIN743201212ComponentFatigueLimitUnderReversedStressSigmaZdWKSigmaBWKTauTWK
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def din743201212_component_yield_point_sigma_zd_fk_sigma_bfk_tau_tfk(
        self: "Self",
    ) -> "_44.StressMeasurementShaftAxialBendingTorsionalComponentValues":
        """mastapy._private.shafts.StressMeasurementShaftAxialBendingTorsionalComponentValues

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DIN743201212ComponentYieldPointSigmaZdFKSigmaBFKTauTFK

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def din743201212_influence_factor_for_mean_stress_sensitivity_psi_sigma_k_psi_tau_k(
        self: "Self",
    ) -> "_16.ShaftAxialBendingTorsionalComponentValues":
        """mastapy._private.shafts.ShaftAxialBendingTorsionalComponentValues

        Note:
            This property is readonly.
        """
        temp = (
            self.wrapped.DIN743201212InfluenceFactorForMeanStressSensitivityPsiSigmaKPsiTauK
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def fkm_guideline_6th_edition_2012_cyclic_degree_of_utilization_for_finite_life(
        self: "Self",
    ) -> "_17.ShaftAxialBendingXBendingYTorsionalComponentValues":
        """mastapy._private.shafts.ShaftAxialBendingXBendingYTorsionalComponentValues

        Note:
            This property is readonly.
        """
        temp = (
            self.wrapped.FKMGuideline6thEdition2012CyclicDegreeOfUtilizationForFiniteLife
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def fkm_guideline_6th_edition_2012_cyclic_degree_of_utilization_for_infinite_life(
        self: "Self",
    ) -> "_17.ShaftAxialBendingXBendingYTorsionalComponentValues":
        """mastapy._private.shafts.ShaftAxialBendingXBendingYTorsionalComponentValues

        Note:
            This property is readonly.
        """
        temp = (
            self.wrapped.FKMGuideline6thEdition2012CyclicDegreeOfUtilizationForInfiniteLife
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def sn_curve(self: "Self") -> "_292.SNCurve":
        """mastapy._private.materials.SNCurve

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SNCurve

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def sn_curve_axial(self: "Self") -> "_292.SNCurve":
        """mastapy._private.materials.SNCurve

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SNCurveAxial

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def sn_curve_bending_x(self: "Self") -> "_292.SNCurve":
        """mastapy._private.materials.SNCurve

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SNCurveBendingX

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def sn_curve_bending_y(self: "Self") -> "_292.SNCurve":
        """mastapy._private.materials.SNCurve

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SNCurveBendingY

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def sn_curve_torsional(self: "Self") -> "_292.SNCurve":
        """mastapy._private.materials.SNCurve

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SNCurveTorsional

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def stress_concentration_factors(
        self: "Self",
    ) -> "_16.ShaftAxialBendingTorsionalComponentValues":
        """mastapy._private.shafts.ShaftAxialBendingTorsionalComponentValues

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StressConcentrationFactors

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def din743201212_stress_amplitude_of_component_fatigue_strength_sigma_zd_adk_sigma_badk_tau_tadk(
        self: "Self",
    ) -> "List[_44.StressMeasurementShaftAxialBendingTorsionalComponentValues]":
        """List[mastapy._private.shafts.StressMeasurementShaftAxialBendingTorsionalComponentValues]

        Note:
            This property is readonly.
        """
        temp = (
            self.wrapped.DIN743201212StressAmplitudeOfComponentFatigueStrengthSigmaZdADKSigmaBADKTauTADK
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def stress_cycles(self: "Self") -> "List[_29.ShaftPointStressCycleReporting]":
        """List[mastapy._private.shafts.ShaftPointStressCycleReporting]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StressCycles

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else "")

    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else "")

    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else "")

    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(
            report_name if report_name else ""
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_ShaftSectionEndDamageResults":
        """Cast to another type.

        Returns:
            _Cast_ShaftSectionEndDamageResults
        """
        return _Cast_ShaftSectionEndDamageResults(self)



"""ConsoleProgress"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import utility
from mastapy._private import _7724
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CONSOLE_PROGRESS = python_net_import("SMT.MastaAPIUtility", "ConsoleProgress")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ConsoleProgress")
    CastSelf = TypeVar("CastSelf", bound="ConsoleProgress._Cast_ConsoleProgress")


__docformat__ = "restructuredtext en"
__all__ = ("ConsoleProgress",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConsoleProgress:
    """Special nested class for casting ConsoleProgress to subclasses."""

    __parent__: "ConsoleProgress"

    @property
    def console_progress(self: "CastSelf") -> "ConsoleProgress":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ConsoleProgress(_7724.TaskProgress):
    """ConsoleProgress

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONSOLE_PROGRESS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def id(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Id

        if temp is None:
            return 0

        return temp

    @enforce_parameter_types
    def add_error(self: "Self", error: "str") -> None:
        """Method does not return.

        Args:
            error (str)
        """
        error = str(error)
        self.wrapped.AddError(error if error else "")

    def complete(self: "Self") -> None:
        """Method does not return."""
        self.wrapped.Complete()

    @property
    def cast_to(self: "Self") -> "_Cast_ConsoleProgress":
        """Cast to another type.

        Returns:
            _Cast_ConsoleProgress
        """
        return _Cast_ConsoleProgress(self)



"""CVTLoadCase"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.static_loads import _6968
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CVT_LOAD_CASE = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads", "CVTLoadCase"
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.system_model.part_model.couplings import _2644
    from mastapy._private.system_model.analyses_and_results.static_loads import (
        _7003,
        _7101,
        _6953,
        _7077,
    )
    from mastapy._private.system_model.analyses_and_results import _2740, _2736, _2734

    Self = TypeVar("Self", bound="CVTLoadCase")
    CastSelf = TypeVar("CastSelf", bound="CVTLoadCase._Cast_CVTLoadCase")


__docformat__ = "restructuredtext en"
__all__ = ("CVTLoadCase",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CVTLoadCase:
    """Special nested class for casting CVTLoadCase to subclasses."""

    __parent__: "CVTLoadCase"

    @property
    def belt_drive_load_case(self: "CastSelf") -> "_6968.BeltDriveLoadCase":
        return self.__parent__._cast(_6968.BeltDriveLoadCase)

    @property
    def specialised_assembly_load_case(
        self: "CastSelf",
    ) -> "_7101.SpecialisedAssemblyLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7101,
        )

        return self.__parent__._cast(_7101.SpecialisedAssemblyLoadCase)

    @property
    def abstract_assembly_load_case(
        self: "CastSelf",
    ) -> "_6953.AbstractAssemblyLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6953,
        )

        return self.__parent__._cast(_6953.AbstractAssemblyLoadCase)

    @property
    def part_load_case(self: "CastSelf") -> "_7077.PartLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7077,
        )

        return self.__parent__._cast(_7077.PartLoadCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2740.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2740

        return self.__parent__._cast(_2740.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2736.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2736

        return self.__parent__._cast(_2736.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def cvt_load_case(self: "CastSelf") -> "CVTLoadCase":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class CVTLoadCase(_6968.BeltDriveLoadCase):
    """CVTLoadCase

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CVT_LOAD_CASE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def speed_ratio(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.SpeedRatio

        if temp is None:
            return 0.0

        return temp

    @speed_ratio.setter
    @enforce_parameter_types
    def speed_ratio(self: "Self", value: "float") -> None:
        self.wrapped.SpeedRatio = float(value) if value is not None else 0.0

    @property
    def assembly_design(self: "Self") -> "_2644.CVT":
        """mastapy._private.system_model.part_model.couplings.CVT

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def pulleys(self: "Self") -> "List[_7003.CVTPulleyLoadCase]":
        """List[mastapy._private.system_model.analyses_and_results.static_loads.CVTPulleyLoadCase]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Pulleys

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_CVTLoadCase":
        """Cast to another type.

        Returns:
            _Cast_CVTLoadCase
        """
        return _Cast_CVTLoadCase(self)



"""StraightBevelDiffGearDesign"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.gears.gear_designs.bevel import _1218
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_STRAIGHT_BEVEL_DIFF_GEAR_DESIGN = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.StraightBevelDiff", "StraightBevelDiffGearDesign"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.gear_designs.bevel import _1223
    from mastapy._private.gears.gear_designs.agma_gleason_conical import _1231
    from mastapy._private.gears.gear_designs.conical import _1192
    from mastapy._private.gears.gear_designs import _971, _972

    Self = TypeVar("Self", bound="StraightBevelDiffGearDesign")
    CastSelf = TypeVar(
        "CastSelf",
        bound="StraightBevelDiffGearDesign._Cast_StraightBevelDiffGearDesign",
    )


__docformat__ = "restructuredtext en"
__all__ = ("StraightBevelDiffGearDesign",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_StraightBevelDiffGearDesign:
    """Special nested class for casting StraightBevelDiffGearDesign to subclasses."""

    __parent__: "StraightBevelDiffGearDesign"

    @property
    def bevel_gear_design(self: "CastSelf") -> "_1218.BevelGearDesign":
        return self.__parent__._cast(_1218.BevelGearDesign)

    @property
    def agma_gleason_conical_gear_design(
        self: "CastSelf",
    ) -> "_1231.AGMAGleasonConicalGearDesign":
        from mastapy._private.gears.gear_designs.agma_gleason_conical import _1231

        return self.__parent__._cast(_1231.AGMAGleasonConicalGearDesign)

    @property
    def conical_gear_design(self: "CastSelf") -> "_1192.ConicalGearDesign":
        from mastapy._private.gears.gear_designs.conical import _1192

        return self.__parent__._cast(_1192.ConicalGearDesign)

    @property
    def gear_design(self: "CastSelf") -> "_971.GearDesign":
        from mastapy._private.gears.gear_designs import _971

        return self.__parent__._cast(_971.GearDesign)

    @property
    def gear_design_component(self: "CastSelf") -> "_972.GearDesignComponent":
        from mastapy._private.gears.gear_designs import _972

        return self.__parent__._cast(_972.GearDesignComponent)

    @property
    def straight_bevel_diff_gear_design(
        self: "CastSelf",
    ) -> "StraightBevelDiffGearDesign":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class StraightBevelDiffGearDesign(_1218.BevelGearDesign):
    """StraightBevelDiffGearDesign

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _STRAIGHT_BEVEL_DIFF_GEAR_DESIGN

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def allowable_peak_bending_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AllowablePeakBendingStress

        if temp is None:
            return 0.0

        return temp

    @property
    def allowable_performance_bending_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AllowablePerformanceBendingStress

        if temp is None:
            return 0.0

        return temp

    @property
    def edge_radius(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EdgeRadius

        if temp is None:
            return 0.0

        return temp

    @edge_radius.setter
    @enforce_parameter_types
    def edge_radius(self: "Self", value: "float") -> None:
        self.wrapped.EdgeRadius = float(value) if value is not None else 0.0

    @property
    def edge_radius_from(self: "Self") -> "_1223.EdgeRadiusType":
        """mastapy._private.gears.gear_designs.bevel.EdgeRadiusType"""
        temp = self.wrapped.EdgeRadiusFrom

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Gears.GearDesigns.Bevel.EdgeRadiusType"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.gear_designs.bevel._1223", "EdgeRadiusType"
        )(value)

    @edge_radius_from.setter
    @enforce_parameter_types
    def edge_radius_from(self: "Self", value: "_1223.EdgeRadiusType") -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Gears.GearDesigns.Bevel.EdgeRadiusType"
        )
        self.wrapped.EdgeRadiusFrom = value

    @property
    def limited_point_width_large_end(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LimitedPointWidthLargeEnd

        if temp is None:
            return 0.0

        return temp

    @property
    def limited_point_width_small_end(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LimitedPointWidthSmallEnd

        if temp is None:
            return 0.0

        return temp

    @property
    def max_radius_cutter_blades(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaxRadiusCutterBlades

        if temp is None:
            return 0.0

        return temp

    @property
    def max_radius_interference(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaxRadiusInterference

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_edge_radius(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumEdgeRadius

        if temp is None:
            return 0.0

        return temp

    @property
    def outer_chordal_addendum(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OuterChordalAddendum

        if temp is None:
            return 0.0

        return temp

    @property
    def outer_chordal_thickness(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OuterChordalThickness

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_StraightBevelDiffGearDesign":
        """Cast to another type.

        Returns:
            _Cast_StraightBevelDiffGearDesign
        """
        return _Cast_StraightBevelDiffGearDesign(self)



"""ThreePointContactBallBearing"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal.implicit import overridable
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private._internal import constructor, utility
from mastapy._private.bearings.bearing_designs.rolling import _2212
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_THREE_POINT_CONTACT_BALL_BEARING = python_net_import(
    "SMT.MastaAPI.Bearings.BearingDesigns.Rolling", "ThreePointContactBallBearing"
)

if TYPE_CHECKING:
    from typing import Any, Type, Union, Tuple, TypeVar

    from mastapy._private.bearings.bearing_designs.rolling import _2193, _2218
    from mastapy._private.bearings.bearing_designs import _2184, _2187, _2183

    Self = TypeVar("Self", bound="ThreePointContactBallBearing")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ThreePointContactBallBearing._Cast_ThreePointContactBallBearing",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ThreePointContactBallBearing",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ThreePointContactBallBearing:
    """Special nested class for casting ThreePointContactBallBearing to subclasses."""

    __parent__: "ThreePointContactBallBearing"

    @property
    def multi_point_contact_ball_bearing(
        self: "CastSelf",
    ) -> "_2212.MultiPointContactBallBearing":
        return self.__parent__._cast(_2212.MultiPointContactBallBearing)

    @property
    def ball_bearing(self: "CastSelf") -> "_2193.BallBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2193

        return self.__parent__._cast(_2193.BallBearing)

    @property
    def rolling_bearing(self: "CastSelf") -> "_2218.RollingBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2218

        return self.__parent__._cast(_2218.RollingBearing)

    @property
    def detailed_bearing(self: "CastSelf") -> "_2184.DetailedBearing":
        from mastapy._private.bearings.bearing_designs import _2184

        return self.__parent__._cast(_2184.DetailedBearing)

    @property
    def non_linear_bearing(self: "CastSelf") -> "_2187.NonLinearBearing":
        from mastapy._private.bearings.bearing_designs import _2187

        return self.__parent__._cast(_2187.NonLinearBearing)

    @property
    def bearing_design(self: "CastSelf") -> "_2183.BearingDesign":
        from mastapy._private.bearings.bearing_designs import _2183

        return self.__parent__._cast(_2183.BearingDesign)

    @property
    def three_point_contact_ball_bearing(
        self: "CastSelf",
    ) -> "ThreePointContactBallBearing":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ThreePointContactBallBearing(_2212.MultiPointContactBallBearing):
    """ThreePointContactBallBearing

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _THREE_POINT_CONTACT_BALL_BEARING

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def assembly_radial_internal_clearance(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.AssemblyRadialInternalClearance

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @assembly_radial_internal_clearance.setter
    @enforce_parameter_types
    def assembly_radial_internal_clearance(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.AssemblyRadialInternalClearance = value

    @property
    def inner_shim_angle(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.InnerShimAngle

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @inner_shim_angle.setter
    @enforce_parameter_types
    def inner_shim_angle(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.InnerShimAngle = value

    @property
    def inner_shim_width(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.InnerShimWidth

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @inner_shim_width.setter
    @enforce_parameter_types
    def inner_shim_width(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.InnerShimWidth = value

    @property
    def cast_to(self: "Self") -> "_Cast_ThreePointContactBallBearing":
        """Cast to another type.

        Returns:
            _Cast_ThreePointContactBallBearing
        """
        return _Cast_ThreePointContactBallBearing(self)



"""ConceptCouplingHalfCompoundMultibodyDynamicsAnalysis"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
    _5696,
)
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CONCEPT_COUPLING_HALF_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses.Compound",
    "ConceptCouplingHalfCompoundMultibodyDynamicsAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.system_model.part_model.couplings import _2639
    from mastapy._private.system_model.analyses_and_results.mbd_analyses import _5530
    from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
        _5736,
        _5682,
        _5738,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7711,
        _7708,
    )
    from mastapy._private.system_model.analyses_and_results import _2734

    Self = TypeVar("Self", bound="ConceptCouplingHalfCompoundMultibodyDynamicsAnalysis")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ConceptCouplingHalfCompoundMultibodyDynamicsAnalysis._Cast_ConceptCouplingHalfCompoundMultibodyDynamicsAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConceptCouplingHalfCompoundMultibodyDynamicsAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConceptCouplingHalfCompoundMultibodyDynamicsAnalysis:
    """Special nested class for casting ConceptCouplingHalfCompoundMultibodyDynamicsAnalysis to subclasses."""

    __parent__: "ConceptCouplingHalfCompoundMultibodyDynamicsAnalysis"

    @property
    def coupling_half_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5696.CouplingHalfCompoundMultibodyDynamicsAnalysis":
        return self.__parent__._cast(
            _5696.CouplingHalfCompoundMultibodyDynamicsAnalysis
        )

    @property
    def mountable_component_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5736.MountableComponentCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5736,
        )

        return self.__parent__._cast(
            _5736.MountableComponentCompoundMultibodyDynamicsAnalysis
        )

    @property
    def component_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5682.ComponentCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5682,
        )

        return self.__parent__._cast(_5682.ComponentCompoundMultibodyDynamicsAnalysis)

    @property
    def part_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5738.PartCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5738,
        )

        return self.__parent__._cast(_5738.PartCompoundMultibodyDynamicsAnalysis)

    @property
    def part_compound_analysis(self: "CastSelf") -> "_7711.PartCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7711,
        )

        return self.__parent__._cast(_7711.PartCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7708.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7708,
        )

        return self.__parent__._cast(_7708.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def concept_coupling_half_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "ConceptCouplingHalfCompoundMultibodyDynamicsAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ConceptCouplingHalfCompoundMultibodyDynamicsAnalysis(
    _5696.CouplingHalfCompoundMultibodyDynamicsAnalysis
):
    """ConceptCouplingHalfCompoundMultibodyDynamicsAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONCEPT_COUPLING_HALF_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def component_design(self: "Self") -> "_2639.ConceptCouplingHalf":
        """mastapy._private.system_model.part_model.couplings.ConceptCouplingHalf

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def component_analysis_cases_ready(
        self: "Self",
    ) -> "List[_5530.ConceptCouplingHalfMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.ConceptCouplingHalfMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentAnalysisCasesReady

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def component_analysis_cases(
        self: "Self",
    ) -> "List[_5530.ConceptCouplingHalfMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.ConceptCouplingHalfMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentAnalysisCases

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_ConceptCouplingHalfCompoundMultibodyDynamicsAnalysis":
        """Cast to another type.

        Returns:
            _Cast_ConceptCouplingHalfCompoundMultibodyDynamicsAnalysis
        """
        return _Cast_ConceptCouplingHalfCompoundMultibodyDynamicsAnalysis(self)



"""ThicknessType"""
from __future__ import annotations

from typing import TYPE_CHECKING
from enum import Enum

from mastapy._private._internal.python_net import python_net_import

_THICKNESS_TYPE = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.Cylindrical", "ThicknessType"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ThicknessType")
    CastSelf = TypeVar("CastSelf", bound="ThicknessType._Cast_ThicknessType")


__docformat__ = "restructuredtext en"
__all__ = ("ThicknessType",)


class ThicknessType(Enum):
    """ThicknessType

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _THICKNESS_TYPE

    UNSPECIFIED = 0
    NORMAL_THICKNESS = 1
    CHORDAL_SPAN = 2
    OVER_BALLS = 3
    TRANSVERSE_THICKNESS = 4
    PROFILE_SHIFT = 5
    NORMAL_THICKNESS_AT_DIAMETER = 6
    TRANSVERSE_THICKNESS_AT_DIAMETER = 7
    OVER_TWO_PINS_FREE_PIN_METHOD = 8
    OVER_TWO_PINS_TRANSVERSE_METHOD = 9
    PROFILE_SHIFT_COEFFICIENT = 1024
    CALCULATED = -2
    SPECIFICATION_FROM_STANDARD = -1


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


ThicknessType.__setattr__ = __enum_setattr
ThicknessType.__delattr__ = __enum_delattr



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1169 import (
        AGMA2000A88AccuracyGrader,
    )
    from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1170 import (
        AGMA20151A01AccuracyGrader,
    )
    from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1171 import (
        AGMA20151AccuracyGrades,
    )
    from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1172 import (
        AGMAISO13281B14AccuracyGrader,
    )
    from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1173 import (
        Customer102AGMA2000AccuracyGrader,
    )
    from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1174 import (
        CylindricalAccuracyGrader,
    )
    from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1175 import (
        CylindricalAccuracyGraderWithProfileFormAndSlope,
    )
    from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1176 import (
        CylindricalAccuracyGrades,
    )
    from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1177 import (
        CylindricalGearAccuracyTolerances,
    )
    from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1178 import (
        DIN3967SystemOfGearFits,
    )
    from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1179 import (
        ISO132811995AccuracyGrader,
    )
    from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1180 import (
        ISO132812013AccuracyGrader,
    )
    from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1181 import (
        ISO1328AccuracyGraderCommon,
    )
    from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1182 import (
        ISO1328AccuracyGrades,
    )
    from mastapy._private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1183 import (
        OverridableTolerance,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1169": [
            "AGMA2000A88AccuracyGrader"
        ],
        "_private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1170": [
            "AGMA20151A01AccuracyGrader"
        ],
        "_private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1171": [
            "AGMA20151AccuracyGrades"
        ],
        "_private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1172": [
            "AGMAISO13281B14AccuracyGrader"
        ],
        "_private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1173": [
            "Customer102AGMA2000AccuracyGrader"
        ],
        "_private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1174": [
            "CylindricalAccuracyGrader"
        ],
        "_private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1175": [
            "CylindricalAccuracyGraderWithProfileFormAndSlope"
        ],
        "_private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1176": [
            "CylindricalAccuracyGrades"
        ],
        "_private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1177": [
            "CylindricalGearAccuracyTolerances"
        ],
        "_private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1178": [
            "DIN3967SystemOfGearFits"
        ],
        "_private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1179": [
            "ISO132811995AccuracyGrader"
        ],
        "_private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1180": [
            "ISO132812013AccuracyGrader"
        ],
        "_private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1181": [
            "ISO1328AccuracyGraderCommon"
        ],
        "_private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1182": [
            "ISO1328AccuracyGrades"
        ],
        "_private.gears.gear_designs.cylindrical.accuracy_and_tolerances._1183": [
            "OverridableTolerance"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AGMA2000A88AccuracyGrader",
    "AGMA20151A01AccuracyGrader",
    "AGMA20151AccuracyGrades",
    "AGMAISO13281B14AccuracyGrader",
    "Customer102AGMA2000AccuracyGrader",
    "CylindricalAccuracyGrader",
    "CylindricalAccuracyGraderWithProfileFormAndSlope",
    "CylindricalAccuracyGrades",
    "CylindricalGearAccuracyTolerances",
    "DIN3967SystemOfGearFits",
    "ISO132811995AccuracyGrader",
    "ISO132812013AccuracyGrader",
    "ISO1328AccuracyGraderCommon",
    "ISO1328AccuracyGrades",
    "OverridableTolerance",
)



"""PIDControlSettings"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_PID_CONTROL_SETTINGS = python_net_import(
    "SMT.MastaAPI.MathUtility.Control", "PIDControlSettings"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.math_utility.measured_data import _1611
    from mastapy._private.math_utility import _1569

    Self = TypeVar("Self", bound="PIDControlSettings")
    CastSelf = TypeVar("CastSelf", bound="PIDControlSettings._Cast_PIDControlSettings")


__docformat__ = "restructuredtext en"
__all__ = ("PIDControlSettings",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_PIDControlSettings:
    """Special nested class for casting PIDControlSettings to subclasses."""

    __parent__: "PIDControlSettings"

    @property
    def pid_control_settings(self: "CastSelf") -> "PIDControlSettings":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class PIDControlSettings(_0.APIBase):
    """PIDControlSettings

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _PID_CONTROL_SETTINGS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def control_start_time(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.ControlStartTime

        if temp is None:
            return 0.0

        return temp

    @control_start_time.setter
    @enforce_parameter_types
    def control_start_time(self: "Self", value: "float") -> None:
        self.wrapped.ControlStartTime = float(value) if value is not None else 0.0

    @property
    def differential_gain(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.DifferentialGain

        if temp is None:
            return 0.0

        return temp

    @differential_gain.setter
    @enforce_parameter_types
    def differential_gain(self: "Self", value: "float") -> None:
        self.wrapped.DifferentialGain = float(value) if value is not None else 0.0

    @property
    def differential_gain_vs_time_and_error(
        self: "Self",
    ) -> "_1611.GriddedSurfaceAccessor":
        """mastapy._private.math_utility.measured_data.GriddedSurfaceAccessor"""
        temp = self.wrapped.DifferentialGainVsTimeAndError

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @differential_gain_vs_time_and_error.setter
    @enforce_parameter_types
    def differential_gain_vs_time_and_error(
        self: "Self", value: "_1611.GriddedSurfaceAccessor"
    ) -> None:
        self.wrapped.DifferentialGainVsTimeAndError = value.wrapped

    @property
    def differential_time_constant(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DifferentialTimeConstant

        if temp is None:
            return 0.0

        return temp

    @property
    def integral_gain(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.IntegralGain

        if temp is None:
            return 0.0

        return temp

    @integral_gain.setter
    @enforce_parameter_types
    def integral_gain(self: "Self", value: "float") -> None:
        self.wrapped.IntegralGain = float(value) if value is not None else 0.0

    @property
    def integral_gain_vs_time_and_error(self: "Self") -> "_1611.GriddedSurfaceAccessor":
        """mastapy._private.math_utility.measured_data.GriddedSurfaceAccessor"""
        temp = self.wrapped.IntegralGainVsTimeAndError

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @integral_gain_vs_time_and_error.setter
    @enforce_parameter_types
    def integral_gain_vs_time_and_error(
        self: "Self", value: "_1611.GriddedSurfaceAccessor"
    ) -> None:
        self.wrapped.IntegralGainVsTimeAndError = value.wrapped

    @property
    def integral_time_constant(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.IntegralTimeConstant

        if temp is None:
            return 0.0

        return temp

    @property
    def max_change_in_manipulated_value_per_unit_time(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.MaxChangeInManipulatedValuePerUnitTime

        if temp is None:
            return 0.0

        return temp

    @max_change_in_manipulated_value_per_unit_time.setter
    @enforce_parameter_types
    def max_change_in_manipulated_value_per_unit_time(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.MaxChangeInManipulatedValuePerUnitTime = (
            float(value) if value is not None else 0.0
        )

    @property
    def max_manipulated_value(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.MaxManipulatedValue

        if temp is None:
            return 0.0

        return temp

    @max_manipulated_value.setter
    @enforce_parameter_types
    def max_manipulated_value(self: "Self", value: "float") -> None:
        self.wrapped.MaxManipulatedValue = float(value) if value is not None else 0.0

    @property
    def min_manipulated_value(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.MinManipulatedValue

        if temp is None:
            return 0.0

        return temp

    @min_manipulated_value.setter
    @enforce_parameter_types
    def min_manipulated_value(self: "Self", value: "float") -> None:
        self.wrapped.MinManipulatedValue = float(value) if value is not None else 0.0

    @property
    def pid_calculates_change_in_manipulated_value(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.PIDCalculatesChangeInManipulatedValue

        if temp is None:
            return False

        return temp

    @pid_calculates_change_in_manipulated_value.setter
    @enforce_parameter_types
    def pid_calculates_change_in_manipulated_value(self: "Self", value: "bool") -> None:
        self.wrapped.PIDCalculatesChangeInManipulatedValue = (
            bool(value) if value is not None else False
        )

    @property
    def proportional_gain(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.ProportionalGain

        if temp is None:
            return 0.0

        return temp

    @proportional_gain.setter
    @enforce_parameter_types
    def proportional_gain(self: "Self", value: "float") -> None:
        self.wrapped.ProportionalGain = float(value) if value is not None else 0.0

    @property
    def proportional_gain_vs_time_and_error(
        self: "Self",
    ) -> "_1611.GriddedSurfaceAccessor":
        """mastapy._private.math_utility.measured_data.GriddedSurfaceAccessor"""
        temp = self.wrapped.ProportionalGainVsTimeAndError

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @proportional_gain_vs_time_and_error.setter
    @enforce_parameter_types
    def proportional_gain_vs_time_and_error(
        self: "Self", value: "_1611.GriddedSurfaceAccessor"
    ) -> None:
        self.wrapped.ProportionalGainVsTimeAndError = value.wrapped

    @property
    def set_point_value(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.SetPointValue

        if temp is None:
            return 0.0

        return temp

    @set_point_value.setter
    @enforce_parameter_types
    def set_point_value(self: "Self", value: "float") -> None:
        self.wrapped.SetPointValue = float(value) if value is not None else 0.0

    @property
    def update_frequency(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.UpdateFrequency

        if temp is None:
            return 0.0

        return temp

    @update_frequency.setter
    @enforce_parameter_types
    def update_frequency(self: "Self", value: "float") -> None:
        self.wrapped.UpdateFrequency = float(value) if value is not None else 0.0

    @property
    def update_method(self: "Self") -> "_1569.PIDControlUpdateMethod":
        """mastapy._private.math_utility.PIDControlUpdateMethod"""
        temp = self.wrapped.UpdateMethod

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.MathUtility.PIDControlUpdateMethod"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.math_utility._1569", "PIDControlUpdateMethod"
        )(value)

    @update_method.setter
    @enforce_parameter_types
    def update_method(self: "Self", value: "_1569.PIDControlUpdateMethod") -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.MathUtility.PIDControlUpdateMethod"
        )
        self.wrapped.UpdateMethod = value

    @property
    def update_time(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.UpdateTime

        if temp is None:
            return 0.0

        return temp

    @update_time.setter
    @enforce_parameter_types
    def update_time(self: "Self", value: "float") -> None:
        self.wrapped.UpdateTime = float(value) if value is not None else 0.0

    @property
    def use_differential_gain_scheduling(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.UseDifferentialGainScheduling

        if temp is None:
            return False

        return temp

    @use_differential_gain_scheduling.setter
    @enforce_parameter_types
    def use_differential_gain_scheduling(self: "Self", value: "bool") -> None:
        self.wrapped.UseDifferentialGainScheduling = (
            bool(value) if value is not None else False
        )

    @property
    def use_integral_gain_scheduling(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.UseIntegralGainScheduling

        if temp is None:
            return False

        return temp

    @use_integral_gain_scheduling.setter
    @enforce_parameter_types
    def use_integral_gain_scheduling(self: "Self", value: "bool") -> None:
        self.wrapped.UseIntegralGainScheduling = (
            bool(value) if value is not None else False
        )

    @property
    def use_integrator_anti_windup(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.UseIntegratorAntiWindup

        if temp is None:
            return False

        return temp

    @use_integrator_anti_windup.setter
    @enforce_parameter_types
    def use_integrator_anti_windup(self: "Self", value: "bool") -> None:
        self.wrapped.UseIntegratorAntiWindup = (
            bool(value) if value is not None else False
        )

    @property
    def use_proportional_gain_scheduling(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.UseProportionalGainScheduling

        if temp is None:
            return False

        return temp

    @use_proportional_gain_scheduling.setter
    @enforce_parameter_types
    def use_proportional_gain_scheduling(self: "Self", value: "bool") -> None:
        self.wrapped.UseProportionalGainScheduling = (
            bool(value) if value is not None else False
        )

    @property
    def cast_to(self: "Self") -> "_Cast_PIDControlSettings":
        """Cast to another type.

        Returns:
            _Cast_PIDControlSettings
        """
        return _Cast_PIDControlSettings(self)



"""GearSetOptimiser"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, utility
from mastapy._private._internal.python_net import python_net_import
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException

_INT_32 = python_net_import("System", "Int32")
_BOOLEAN = python_net_import("System", "Boolean")
_TASK_PROGRESS = python_net_import("SMT.MastaAPIUtility", "TaskProgress")
_GEAR_SET_OPTIMISER = python_net_import("SMT.MastaAPI.Gears", "GearSetOptimiser")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private import _7724
    from mastapy._private.gears import _341
    from mastapy._private.gears.gear_designs.cylindrical import _1060

    Self = TypeVar("Self", bound="GearSetOptimiser")
    CastSelf = TypeVar("CastSelf", bound="GearSetOptimiser._Cast_GearSetOptimiser")


__docformat__ = "restructuredtext en"
__all__ = ("GearSetOptimiser",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_GearSetOptimiser:
    """Special nested class for casting GearSetOptimiser to subclasses."""

    __parent__: "GearSetOptimiser"

    @property
    def cylindrical_gear_set_macro_geometry_optimiser(
        self: "CastSelf",
    ) -> "_1060.CylindricalGearSetMacroGeometryOptimiser":
        from mastapy._private.gears.gear_designs.cylindrical import _1060

        return self.__parent__._cast(_1060.CylindricalGearSetMacroGeometryOptimiser)

    @property
    def gear_set_optimiser(self: "CastSelf") -> "GearSetOptimiser":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class GearSetOptimiser(_0.APIBase):
    """GearSetOptimiser

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _GEAR_SET_OPTIMISER

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def axial_ratio_rating_for_nvh(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AxialRatioRatingForNVH

        if temp is None:
            return 0.0

        return temp

    @property
    def bending_safety_factor_for_worst_gear(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BendingSafetyFactorForWorstGear

        if temp is None:
            return 0.0

        return temp

    @property
    def contact_safety_factor_for_worst_gear(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactSafetyFactorForWorstGear

        if temp is None:
            return 0.0

        return temp

    @property
    def crack_initiation_safety_factor_for_worst_gear(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CrackInitiationSafetyFactorForWorstGear

        if temp is None:
            return 0.0

        return temp

    @property
    def fatigue_fracture_safety_factor_for_worst_gear(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FatigueFractureSafetyFactorForWorstGear

        if temp is None:
            return 0.0

        return temp

    @property
    def micropitting_safety_factor_for_worst_gear(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MicropittingSafetyFactorForWorstGear

        if temp is None:
            return 0.0

        return temp

    @property
    def permanent_deformation_safety_factor_for_worst_gear(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PermanentDeformationSafetyFactorForWorstGear

        if temp is None:
            return 0.0

        return temp

    @property
    def scuffing_safety_factor_flash_temperature_method_for_worst_gear(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingSafetyFactorFlashTemperatureMethodForWorstGear

        if temp is None:
            return 0.0

        return temp

    @property
    def scuffing_safety_factor_integral_method_for_worst_gear(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingSafetyFactorIntegralMethodForWorstGear

        if temp is None:
            return 0.0

        return temp

    @property
    def static_bending_safety_factor_for_worst_gear(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StaticBendingSafetyFactorForWorstGear

        if temp is None:
            return 0.0

        return temp

    @property
    def static_contact_safety_factor_for_worst_gear(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StaticContactSafetyFactorForWorstGear

        if temp is None:
            return 0.0

        return temp

    @property
    def transverse_and_axial_contact_ratio_rating_for_nvh(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TransverseAndAxialContactRatioRatingForNVH

        if temp is None:
            return 0.0

        return temp

    @property
    def transverse_ratio_rating_for_nvh(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TransverseRatioRatingForNVH

        if temp is None:
            return 0.0

        return temp

    def dispose(self: "Self") -> None:
        """Method does not return."""
        self.wrapped.Dispose()

    @enforce_parameter_types
    def perform_strength_optimisation_with_progress(
        self: "Self",
        number_of_results: "int",
        progress: "_7724.TaskProgress",
        use_current_design_as_starting_point: "bool" = False,
    ) -> "_341.GearSetOptimisationResults":
        """mastapy._private.gears.GearSetOptimisationResults

        Args:
            number_of_results (int)
            progress (mastapy._private.TaskProgress)
            use_current_design_as_starting_point (bool, optional)
        """
        number_of_results = int(number_of_results)
        use_current_design_as_starting_point = bool(
            use_current_design_as_starting_point
        )
        method_result = self.wrapped.PerformStrengthOptimisation.Overloads[
            _INT_32, _TASK_PROGRESS, _BOOLEAN
        ](
            number_of_results if number_of_results else 0,
            progress.wrapped if progress else None,
            use_current_design_as_starting_point
            if use_current_design_as_starting_point
            else False,
        )
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @enforce_parameter_types
    def perform_strength_optimisation(
        self: "Self",
        number_of_results: "int",
        use_current_design_as_starting_point: "bool" = False,
    ) -> "_341.GearSetOptimisationResults":
        """mastapy._private.gears.GearSetOptimisationResults

        Args:
            number_of_results (int)
            use_current_design_as_starting_point (bool, optional)
        """
        number_of_results = int(number_of_results)
        use_current_design_as_starting_point = bool(
            use_current_design_as_starting_point
        )
        method_result = self.wrapped.PerformStrengthOptimisation.Overloads[
            _INT_32, _BOOLEAN
        ](
            number_of_results if number_of_results else 0,
            use_current_design_as_starting_point
            if use_current_design_as_starting_point
            else False,
        )
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    def __enter__(self: "Self") -> None:
        return self

    def __exit__(
        self: "Self", exception_type: "Any", exception_value: "Any", traceback: "Any"
    ) -> None:
        self.dispose()

    @property
    def cast_to(self: "Self") -> "_Cast_GearSetOptimiser":
        """Cast to another type.

        Returns:
            _Cast_GearSetOptimiser
        """
        return _Cast_GearSetOptimiser(self)



"""CoefficientOfFrictionCalculator"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import conversion, utility
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_COEFFICIENT_OF_FRICTION_CALCULATOR = python_net_import(
    "SMT.MastaAPI.Gears.Materials", "CoefficientOfFrictionCalculator"
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.gears.materials import (
        _595,
        _607,
        _611,
        _612,
        _613,
        _614,
        _615,
        _617,
        _623,
        _624,
        _630,
    )

    Self = TypeVar("Self", bound="CoefficientOfFrictionCalculator")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CoefficientOfFrictionCalculator._Cast_CoefficientOfFrictionCalculator",
    )


__docformat__ = "restructuredtext en"
__all__ = ("CoefficientOfFrictionCalculator",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CoefficientOfFrictionCalculator:
    """Special nested class for casting CoefficientOfFrictionCalculator to subclasses."""

    __parent__: "CoefficientOfFrictionCalculator"

    @property
    def benedict_and_kelley_coefficient_of_friction_calculator(
        self: "CastSelf",
    ) -> "_595.BenedictAndKelleyCoefficientOfFrictionCalculator":
        from mastapy._private.gears.materials import _595

        return self.__parent__._cast(
            _595.BenedictAndKelleyCoefficientOfFrictionCalculator
        )

    @property
    def drozdov_and_gavrikov_coefficient_of_friction_calculator(
        self: "CastSelf",
    ) -> "_607.DrozdovAndGavrikovCoefficientOfFrictionCalculator":
        from mastapy._private.gears.materials import _607

        return self.__parent__._cast(
            _607.DrozdovAndGavrikovCoefficientOfFrictionCalculator
        )

    @property
    def instantaneous_coefficient_of_friction_calculator(
        self: "CastSelf",
    ) -> "_611.InstantaneousCoefficientOfFrictionCalculator":
        from mastapy._private.gears.materials import _611

        return self.__parent__._cast(_611.InstantaneousCoefficientOfFrictionCalculator)

    @property
    def iso14179_part_1_coefficient_of_friction_calculator(
        self: "CastSelf",
    ) -> "_612.ISO14179Part1CoefficientOfFrictionCalculator":
        from mastapy._private.gears.materials import _612

        return self.__parent__._cast(_612.ISO14179Part1CoefficientOfFrictionCalculator)

    @property
    def iso14179_part_2_coefficient_of_friction_calculator(
        self: "CastSelf",
    ) -> "_613.ISO14179Part2CoefficientOfFrictionCalculator":
        from mastapy._private.gears.materials import _613

        return self.__parent__._cast(_613.ISO14179Part2CoefficientOfFrictionCalculator)

    @property
    def iso14179_part_2_coefficient_of_friction_calculator_base(
        self: "CastSelf",
    ) -> "_614.ISO14179Part2CoefficientOfFrictionCalculatorBase":
        from mastapy._private.gears.materials import _614

        return self.__parent__._cast(
            _614.ISO14179Part2CoefficientOfFrictionCalculatorBase
        )

    @property
    def iso14179_part_2_coefficient_of_friction_calculator_with_martins_modification(
        self: "CastSelf",
    ) -> "_615.ISO14179Part2CoefficientOfFrictionCalculatorWithMartinsModification":
        from mastapy._private.gears.materials import _615

        return self.__parent__._cast(
            _615.ISO14179Part2CoefficientOfFrictionCalculatorWithMartinsModification
        )

    @property
    def isotc60_coefficient_of_friction_calculator(
        self: "CastSelf",
    ) -> "_617.ISOTC60CoefficientOfFrictionCalculator":
        from mastapy._private.gears.materials import _617

        return self.__parent__._cast(_617.ISOTC60CoefficientOfFrictionCalculator)

    @property
    def misharin_coefficient_of_friction_calculator(
        self: "CastSelf",
    ) -> "_623.MisharinCoefficientOfFrictionCalculator":
        from mastapy._private.gears.materials import _623

        return self.__parent__._cast(_623.MisharinCoefficientOfFrictionCalculator)

    @property
    def o_donoghue_and_cameron_coefficient_of_friction_calculator(
        self: "CastSelf",
    ) -> "_624.ODonoghueAndCameronCoefficientOfFrictionCalculator":
        from mastapy._private.gears.materials import _624

        return self.__parent__._cast(
            _624.ODonoghueAndCameronCoefficientOfFrictionCalculator
        )

    @property
    def script_coefficient_of_friction_calculator(
        self: "CastSelf",
    ) -> "_630.ScriptCoefficientOfFrictionCalculator":
        from mastapy._private.gears.materials import _630

        return self.__parent__._cast(_630.ScriptCoefficientOfFrictionCalculator)

    @property
    def coefficient_of_friction_calculator(
        self: "CastSelf",
    ) -> "CoefficientOfFrictionCalculator":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class CoefficientOfFrictionCalculator(_0.APIBase):
    """CoefficientOfFrictionCalculator

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _COEFFICIENT_OF_FRICTION_CALCULATOR

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else "")

    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else "")

    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else "")

    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(
            report_name if report_name else ""
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_CoefficientOfFrictionCalculator":
        """Cast to another type.

        Returns:
            _Cast_CoefficientOfFrictionCalculator
        """
        return _Cast_CoefficientOfFrictionCalculator(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6415 import (
        AbstractAssemblyDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6416 import (
        AbstractShaftDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6417 import (
        AbstractShaftOrHousingDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6418 import (
        AbstractShaftToMountableComponentConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6419 import (
        AGMAGleasonConicalGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6420 import (
        AGMAGleasonConicalGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6421 import (
        AGMAGleasonConicalGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6422 import (
        AssemblyDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6423 import (
        BearingDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6424 import (
        BeltConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6425 import (
        BeltDriveDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6426 import (
        BevelDifferentialGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6427 import (
        BevelDifferentialGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6428 import (
        BevelDifferentialGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6429 import (
        BevelDifferentialPlanetGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6430 import (
        BevelDifferentialSunGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6431 import (
        BevelGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6432 import (
        BevelGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6433 import (
        BevelGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6434 import (
        BoltDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6435 import (
        BoltedJointDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6436 import (
        ClutchConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6437 import (
        ClutchDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6438 import (
        ClutchHalfDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6439 import (
        CoaxialConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6440 import (
        ComponentDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6441 import (
        ConceptCouplingConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6442 import (
        ConceptCouplingDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6443 import (
        ConceptCouplingHalfDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6444 import (
        ConceptGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6445 import (
        ConceptGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6446 import (
        ConceptGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6447 import (
        ConicalGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6448 import (
        ConicalGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6449 import (
        ConicalGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6450 import (
        ConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6451 import (
        ConnectorDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6452 import (
        CouplingConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6453 import (
        CouplingDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6454 import (
        CouplingHalfDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6455 import (
        CVTBeltConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6456 import (
        CVTDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6457 import (
        CVTPulleyDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6458 import (
        CycloidalAssemblyDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6459 import (
        CycloidalDiscCentralBearingConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6460 import (
        CycloidalDiscDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6461 import (
        CycloidalDiscPlanetaryBearingConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6462 import (
        CylindricalGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6463 import (
        CylindricalGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6464 import (
        CylindricalGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6465 import (
        CylindricalPlanetGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6466 import (
        DatumDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6467 import (
        DynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6468 import (
        DynamicAnalysisDrawStyle,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6469 import (
        ExternalCADModelDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6470 import (
        FaceGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6471 import (
        FaceGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6472 import (
        FaceGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6473 import (
        FEPartDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6474 import (
        FlexiblePinAssemblyDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6475 import (
        GearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6476 import (
        GearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6477 import (
        GearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6478 import (
        GuideDxfModelDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6479 import (
        HypoidGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6480 import (
        HypoidGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6481 import (
        HypoidGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6482 import (
        InterMountableComponentConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6483 import (
        KlingelnbergCycloPalloidConicalGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6484 import (
        KlingelnbergCycloPalloidConicalGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6485 import (
        KlingelnbergCycloPalloidConicalGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6486 import (
        KlingelnbergCycloPalloidHypoidGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6487 import (
        KlingelnbergCycloPalloidHypoidGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6488 import (
        KlingelnbergCycloPalloidHypoidGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6489 import (
        KlingelnbergCycloPalloidSpiralBevelGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6490 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6491 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6492 import (
        MassDiscDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6493 import (
        MeasurementComponentDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6494 import (
        MicrophoneArrayDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6495 import (
        MicrophoneDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6496 import (
        MountableComponentDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6497 import (
        OilSealDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6498 import (
        PartDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6499 import (
        PartToPartShearCouplingConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6500 import (
        PartToPartShearCouplingDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6501 import (
        PartToPartShearCouplingHalfDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6502 import (
        PlanetaryConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6503 import (
        PlanetaryGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6504 import (
        PlanetCarrierDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6505 import (
        PointLoadDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6506 import (
        PowerLoadDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6507 import (
        PulleyDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6508 import (
        RingPinsDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6509 import (
        RingPinsToDiscConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6510 import (
        RollingRingAssemblyDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6511 import (
        RollingRingConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6512 import (
        RollingRingDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6513 import (
        RootAssemblyDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6514 import (
        ShaftDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6515 import (
        ShaftHubConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6516 import (
        ShaftToMountableComponentConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6517 import (
        SpecialisedAssemblyDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6518 import (
        SpiralBevelGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6519 import (
        SpiralBevelGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6520 import (
        SpiralBevelGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6521 import (
        SpringDamperConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6522 import (
        SpringDamperDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6523 import (
        SpringDamperHalfDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6524 import (
        StraightBevelDiffGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6525 import (
        StraightBevelDiffGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6526 import (
        StraightBevelDiffGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6527 import (
        StraightBevelGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6528 import (
        StraightBevelGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6529 import (
        StraightBevelGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6530 import (
        StraightBevelPlanetGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6531 import (
        StraightBevelSunGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6532 import (
        SynchroniserDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6533 import (
        SynchroniserHalfDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6534 import (
        SynchroniserPartDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6535 import (
        SynchroniserSleeveDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6536 import (
        TorqueConverterConnectionDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6537 import (
        TorqueConverterDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6538 import (
        TorqueConverterPumpDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6539 import (
        TorqueConverterTurbineDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6540 import (
        UnbalancedMassDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6541 import (
        VirtualComponentDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6542 import (
        WormGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6543 import (
        WormGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6544 import (
        WormGearSetDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6545 import (
        ZerolBevelGearDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6546 import (
        ZerolBevelGearMeshDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses._6547 import (
        ZerolBevelGearSetDynamicAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.dynamic_analyses._6415": [
            "AbstractAssemblyDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6416": [
            "AbstractShaftDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6417": [
            "AbstractShaftOrHousingDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6418": [
            "AbstractShaftToMountableComponentConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6419": [
            "AGMAGleasonConicalGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6420": [
            "AGMAGleasonConicalGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6421": [
            "AGMAGleasonConicalGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6422": [
            "AssemblyDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6423": [
            "BearingDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6424": [
            "BeltConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6425": [
            "BeltDriveDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6426": [
            "BevelDifferentialGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6427": [
            "BevelDifferentialGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6428": [
            "BevelDifferentialGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6429": [
            "BevelDifferentialPlanetGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6430": [
            "BevelDifferentialSunGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6431": [
            "BevelGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6432": [
            "BevelGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6433": [
            "BevelGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6434": [
            "BoltDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6435": [
            "BoltedJointDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6436": [
            "ClutchConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6437": [
            "ClutchDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6438": [
            "ClutchHalfDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6439": [
            "CoaxialConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6440": [
            "ComponentDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6441": [
            "ConceptCouplingConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6442": [
            "ConceptCouplingDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6443": [
            "ConceptCouplingHalfDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6444": [
            "ConceptGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6445": [
            "ConceptGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6446": [
            "ConceptGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6447": [
            "ConicalGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6448": [
            "ConicalGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6449": [
            "ConicalGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6450": [
            "ConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6451": [
            "ConnectorDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6452": [
            "CouplingConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6453": [
            "CouplingDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6454": [
            "CouplingHalfDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6455": [
            "CVTBeltConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6456": [
            "CVTDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6457": [
            "CVTPulleyDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6458": [
            "CycloidalAssemblyDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6459": [
            "CycloidalDiscCentralBearingConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6460": [
            "CycloidalDiscDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6461": [
            "CycloidalDiscPlanetaryBearingConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6462": [
            "CylindricalGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6463": [
            "CylindricalGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6464": [
            "CylindricalGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6465": [
            "CylindricalPlanetGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6466": [
            "DatumDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6467": [
            "DynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6468": [
            "DynamicAnalysisDrawStyle"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6469": [
            "ExternalCADModelDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6470": [
            "FaceGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6471": [
            "FaceGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6472": [
            "FaceGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6473": [
            "FEPartDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6474": [
            "FlexiblePinAssemblyDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6475": [
            "GearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6476": [
            "GearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6477": [
            "GearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6478": [
            "GuideDxfModelDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6479": [
            "HypoidGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6480": [
            "HypoidGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6481": [
            "HypoidGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6482": [
            "InterMountableComponentConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6483": [
            "KlingelnbergCycloPalloidConicalGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6484": [
            "KlingelnbergCycloPalloidConicalGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6485": [
            "KlingelnbergCycloPalloidConicalGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6486": [
            "KlingelnbergCycloPalloidHypoidGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6487": [
            "KlingelnbergCycloPalloidHypoidGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6488": [
            "KlingelnbergCycloPalloidHypoidGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6489": [
            "KlingelnbergCycloPalloidSpiralBevelGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6490": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6491": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6492": [
            "MassDiscDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6493": [
            "MeasurementComponentDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6494": [
            "MicrophoneArrayDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6495": [
            "MicrophoneDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6496": [
            "MountableComponentDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6497": [
            "OilSealDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6498": [
            "PartDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6499": [
            "PartToPartShearCouplingConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6500": [
            "PartToPartShearCouplingDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6501": [
            "PartToPartShearCouplingHalfDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6502": [
            "PlanetaryConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6503": [
            "PlanetaryGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6504": [
            "PlanetCarrierDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6505": [
            "PointLoadDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6506": [
            "PowerLoadDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6507": [
            "PulleyDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6508": [
            "RingPinsDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6509": [
            "RingPinsToDiscConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6510": [
            "RollingRingAssemblyDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6511": [
            "RollingRingConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6512": [
            "RollingRingDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6513": [
            "RootAssemblyDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6514": [
            "ShaftDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6515": [
            "ShaftHubConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6516": [
            "ShaftToMountableComponentConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6517": [
            "SpecialisedAssemblyDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6518": [
            "SpiralBevelGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6519": [
            "SpiralBevelGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6520": [
            "SpiralBevelGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6521": [
            "SpringDamperConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6522": [
            "SpringDamperDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6523": [
            "SpringDamperHalfDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6524": [
            "StraightBevelDiffGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6525": [
            "StraightBevelDiffGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6526": [
            "StraightBevelDiffGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6527": [
            "StraightBevelGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6528": [
            "StraightBevelGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6529": [
            "StraightBevelGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6530": [
            "StraightBevelPlanetGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6531": [
            "StraightBevelSunGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6532": [
            "SynchroniserDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6533": [
            "SynchroniserHalfDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6534": [
            "SynchroniserPartDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6535": [
            "SynchroniserSleeveDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6536": [
            "TorqueConverterConnectionDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6537": [
            "TorqueConverterDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6538": [
            "TorqueConverterPumpDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6539": [
            "TorqueConverterTurbineDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6540": [
            "UnbalancedMassDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6541": [
            "VirtualComponentDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6542": [
            "WormGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6543": [
            "WormGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6544": [
            "WormGearSetDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6545": [
            "ZerolBevelGearDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6546": [
            "ZerolBevelGearMeshDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses._6547": [
            "ZerolBevelGearSetDynamicAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyDynamicAnalysis",
    "AbstractShaftDynamicAnalysis",
    "AbstractShaftOrHousingDynamicAnalysis",
    "AbstractShaftToMountableComponentConnectionDynamicAnalysis",
    "AGMAGleasonConicalGearDynamicAnalysis",
    "AGMAGleasonConicalGearMeshDynamicAnalysis",
    "AGMAGleasonConicalGearSetDynamicAnalysis",
    "AssemblyDynamicAnalysis",
    "BearingDynamicAnalysis",
    "BeltConnectionDynamicAnalysis",
    "BeltDriveDynamicAnalysis",
    "BevelDifferentialGearDynamicAnalysis",
    "BevelDifferentialGearMeshDynamicAnalysis",
    "BevelDifferentialGearSetDynamicAnalysis",
    "BevelDifferentialPlanetGearDynamicAnalysis",
    "BevelDifferentialSunGearDynamicAnalysis",
    "BevelGearDynamicAnalysis",
    "BevelGearMeshDynamicAnalysis",
    "BevelGearSetDynamicAnalysis",
    "BoltDynamicAnalysis",
    "BoltedJointDynamicAnalysis",
    "ClutchConnectionDynamicAnalysis",
    "ClutchDynamicAnalysis",
    "ClutchHalfDynamicAnalysis",
    "CoaxialConnectionDynamicAnalysis",
    "ComponentDynamicAnalysis",
    "ConceptCouplingConnectionDynamicAnalysis",
    "ConceptCouplingDynamicAnalysis",
    "ConceptCouplingHalfDynamicAnalysis",
    "ConceptGearDynamicAnalysis",
    "ConceptGearMeshDynamicAnalysis",
    "ConceptGearSetDynamicAnalysis",
    "ConicalGearDynamicAnalysis",
    "ConicalGearMeshDynamicAnalysis",
    "ConicalGearSetDynamicAnalysis",
    "ConnectionDynamicAnalysis",
    "ConnectorDynamicAnalysis",
    "CouplingConnectionDynamicAnalysis",
    "CouplingDynamicAnalysis",
    "CouplingHalfDynamicAnalysis",
    "CVTBeltConnectionDynamicAnalysis",
    "CVTDynamicAnalysis",
    "CVTPulleyDynamicAnalysis",
    "CycloidalAssemblyDynamicAnalysis",
    "CycloidalDiscCentralBearingConnectionDynamicAnalysis",
    "CycloidalDiscDynamicAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionDynamicAnalysis",
    "CylindricalGearDynamicAnalysis",
    "CylindricalGearMeshDynamicAnalysis",
    "CylindricalGearSetDynamicAnalysis",
    "CylindricalPlanetGearDynamicAnalysis",
    "DatumDynamicAnalysis",
    "DynamicAnalysis",
    "DynamicAnalysisDrawStyle",
    "ExternalCADModelDynamicAnalysis",
    "FaceGearDynamicAnalysis",
    "FaceGearMeshDynamicAnalysis",
    "FaceGearSetDynamicAnalysis",
    "FEPartDynamicAnalysis",
    "FlexiblePinAssemblyDynamicAnalysis",
    "GearDynamicAnalysis",
    "GearMeshDynamicAnalysis",
    "GearSetDynamicAnalysis",
    "GuideDxfModelDynamicAnalysis",
    "HypoidGearDynamicAnalysis",
    "HypoidGearMeshDynamicAnalysis",
    "HypoidGearSetDynamicAnalysis",
    "InterMountableComponentConnectionDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetDynamicAnalysis",
    "MassDiscDynamicAnalysis",
    "MeasurementComponentDynamicAnalysis",
    "MicrophoneArrayDynamicAnalysis",
    "MicrophoneDynamicAnalysis",
    "MountableComponentDynamicAnalysis",
    "OilSealDynamicAnalysis",
    "PartDynamicAnalysis",
    "PartToPartShearCouplingConnectionDynamicAnalysis",
    "PartToPartShearCouplingDynamicAnalysis",
    "PartToPartShearCouplingHalfDynamicAnalysis",
    "PlanetaryConnectionDynamicAnalysis",
    "PlanetaryGearSetDynamicAnalysis",
    "PlanetCarrierDynamicAnalysis",
    "PointLoadDynamicAnalysis",
    "PowerLoadDynamicAnalysis",
    "PulleyDynamicAnalysis",
    "RingPinsDynamicAnalysis",
    "RingPinsToDiscConnectionDynamicAnalysis",
    "RollingRingAssemblyDynamicAnalysis",
    "RollingRingConnectionDynamicAnalysis",
    "RollingRingDynamicAnalysis",
    "RootAssemblyDynamicAnalysis",
    "ShaftDynamicAnalysis",
    "ShaftHubConnectionDynamicAnalysis",
    "ShaftToMountableComponentConnectionDynamicAnalysis",
    "SpecialisedAssemblyDynamicAnalysis",
    "SpiralBevelGearDynamicAnalysis",
    "SpiralBevelGearMeshDynamicAnalysis",
    "SpiralBevelGearSetDynamicAnalysis",
    "SpringDamperConnectionDynamicAnalysis",
    "SpringDamperDynamicAnalysis",
    "SpringDamperHalfDynamicAnalysis",
    "StraightBevelDiffGearDynamicAnalysis",
    "StraightBevelDiffGearMeshDynamicAnalysis",
    "StraightBevelDiffGearSetDynamicAnalysis",
    "StraightBevelGearDynamicAnalysis",
    "StraightBevelGearMeshDynamicAnalysis",
    "StraightBevelGearSetDynamicAnalysis",
    "StraightBevelPlanetGearDynamicAnalysis",
    "StraightBevelSunGearDynamicAnalysis",
    "SynchroniserDynamicAnalysis",
    "SynchroniserHalfDynamicAnalysis",
    "SynchroniserPartDynamicAnalysis",
    "SynchroniserSleeveDynamicAnalysis",
    "TorqueConverterConnectionDynamicAnalysis",
    "TorqueConverterDynamicAnalysis",
    "TorqueConverterPumpDynamicAnalysis",
    "TorqueConverterTurbineDynamicAnalysis",
    "UnbalancedMassDynamicAnalysis",
    "VirtualComponentDynamicAnalysis",
    "WormGearDynamicAnalysis",
    "WormGearMeshDynamicAnalysis",
    "WormGearSetDynamicAnalysis",
    "ZerolBevelGearDynamicAnalysis",
    "ZerolBevelGearMeshDynamicAnalysis",
    "ZerolBevelGearSetDynamicAnalysis",
)
